@@ -926,7 +926,7 @@ class Am_Point_Array_Data : public Am_Wrapper
     { return false; }
 
  protected:
-  typedef vector<XPoint> vector_of_XPoints;
+  typedef std::vector<XPoint> vector_of_XPoints;
   vector_of_XPoints points;
 #if 0
   XPoint *ar;
@@ -960,7 +960,7 @@ class Am_Region_Impl : public Am_Region
   void Union(int left, int top, unsigned int width, unsigned int height);
  private:
   // Data members
-  stack<Region> stack;
+  std::stack<Region> stack;
   // Internal functions
   Am_Region_Impl () { }
   // This one is used by class Am_Drawonable_Impl sometimes
