@@ -20,11 +20,6 @@ extern "C" {
 #include <X11/Xatom.h>
 #include <sys/time.h>
 #include <stdlib.h>
-#ifndef NEED_SELECT
-#ifdef GCC
-int select ();
-#endif
-#endif
 #ifdef NEED_UNISTD
 #include <unistd.h>
 #endif
