@@ -179,7 +179,7 @@ class Am_Connection_Data : public Am_Wrapper
 {
   Am_WRAPPER_DATA_DECL (Am_Connection)
 
-    friend Am_Connection;
+    friend class Am_Connection;
 public:
   Am_Connection_Data(void);
   Am_Connection_Data(Am_Connection_Data* prototype);
@@ -498,7 +498,11 @@ void Am_Connection::Handle_Sockets(fd_set *readfds)
 		  << "connection waiting\n" <<std::flush;
 	  else
 	    {
-	      unsigned int i;
+#ifdef _MIPS_SIM_ABI64
+              int i;
+#else
+              socklen_t i;
+#endif
 	      int temp_socket;
 	      struct sockaddr_in sa;
 	      i = sizeof (sa);
